@@ -6,6 +6,8 @@
 ( cd opt/kde/share/doc/HTML/xh/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
 ( cd opt/kde/share/doc/HTML/xh/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/xh/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
+( cd opt/kde/share/doc/HTML/xh/kioslave ; rm -rf common )
+( cd opt/kde/share/doc/HTML/xh/kioslave ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
 ( cd opt/kde/share/doc/HTML/xh/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/xh/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
 ( cd opt/kde/share/doc/HTML/xh/kspell ; rm -rf common )
